@@ -278,7 +278,11 @@ sub _receive_rtp {
 
     DEBUG( 100,"ch=%d payload=%d/%d pt=%d xh=%d padding=%d cc=%d",
 	$channel, $seq, length($payload), $mpt & 0x7f, $xh, $padding, $cc);
-    if ( $targs->{rseq} && $seq<= $targs->{rseq}
+    if ( $targs->{ssrc} && $targs->{ssrc} != $ssrc ) {
+	# RTP stream has changed, reset rseq
+	delete $targs->{rseq};
+    }
+    if ( defined $targs->{rseq} && $seq<= $targs->{rseq}
 	&& $targs->{rseq} - $seq < 60000 ) {
 	DEBUG( 10,"seq=$seq last=$targs->{rseq} - dropped" );
 	return;
@@ -287,7 +291,7 @@ sub _receive_rtp {
 
     if ( ref($writeto)) {
 	# callback
-	invoke_callback($writeto,$payload,$seq,$tstamp,$channel);
+	invoke_callback($writeto,$payload,$seq,$tstamp,$channel,$mpt & 0x7f);
     } elsif ( $writeto ) {
 	# save into file
 	my $fd = $targs->{fdr};
@@ -405,7 +409,7 @@ sub _send_rtp {
 	0x1234,    # source ID
     );
     DEBUG( 100,"send %d bytes to RTP", length($buf));
-    send( $sock,$header.$buf,0,$addr ) || die $!;
+    send( $sock,$header.$buf,0,$addr );
 }
 
 ###########################################################################
